@@ -24,9 +24,7 @@ COCOHUB_AUTHORIZE_SERVICE_ACCOUNT_URL = (
     "https://cocohub.ai/auth/confirm_service_account"
 )
 
-SERVICE_ACCOUNT_PATH = os.environ.get(
-    "AGT_SERVICE_ACCOUNT", "~/.agt_service_account"
-)
+SERVICE_ACCOUNT_PATH = os.environ.get("AGT_SERVICE_ACCOUNT", "~/.agt_service_account")
 
 
 class ComponentYAML(BaseModel):
@@ -50,7 +48,6 @@ class ComponentYAML(BaseModel):
         return v
 
 
-
 class CoCoHubServiceAccount(BaseModel):
     client_id: str
     client_secret: str
